@@ -1,9 +1,11 @@
-from typing import Any, Callable, Dict, List, Tuple, Union, Optional, AsyncGenerator
 import asyncio
 import logging
+import yaml
 from contextlib import asynccontextmanager
+from dotenv import load_dotenv
 from fastapi import FastAPI, applications
 from pydantic import BaseModel
+from typing import Any, Callable, Dict, List, Tuple, Union, Optional, AsyncGenerator
 from sycommon.config.Config import SingletonMeta
 from sycommon.models.mqlistener_config import RabbitMQListenerConfig
 from sycommon.models.mqsend_config import RabbitMQSendConfig
@@ -19,6 +21,7 @@ class Services(metaclass=SingletonMeta):
     _mq_tasks: List[asyncio.Task] = []
     _instance: Optional['Services'] = None
     _app: Optional[FastAPI] = None
+    _user_lifespan: Optional[Callable] = None
 
     def __init__(self, config: dict, app: FastAPI):
         if not Services._config:
@@ -40,7 +43,7 @@ class Services(metaclass=SingletonMeta):
     def plugins(
         cls,
         app: FastAPI,
-        config: dict,
+        config: Optional[dict] = None,
         middleware: Optional[Callable[[FastAPI, dict], None]] = None,
         nacos_service: Optional[Callable[[dict], None]] = None,
         logging_service: Optional[Callable[[dict], None]] = None,
@@ -51,12 +54,20 @@ class Services(metaclass=SingletonMeta):
         rabbitmq_listeners: Optional[List[RabbitMQListenerConfig]] = None,
         rabbitmq_senders: Optional[List[RabbitMQSendConfig]] = None
     ) -> FastAPI:
+        load_dotenv()
         # 保存应用实例和配置
         cls._app = app
         cls._config = config
+        cls._user_lifespan = app.router.lifespan_context
         # 设置文档
         applications.get_swagger_ui_html = custom_swagger_ui_html
         applications.get_redoc_html = custom_redoc_html
+        # 设置app.state host, port
+        if not cls._config:
+            config = yaml.safe_load(open('app.yaml', 'r', encoding='utf-8'))
+            cls._config = config
+        app.host = cls._config.get('Host')
+        app.post = cls._config.get('Port')
 
         # 立即配置非异步服务（在应用启动前）
         if middleware:
@@ -71,20 +82,15 @@ class Services(metaclass=SingletonMeta):
         if database_service:
             cls._setup_database_static(database_service, config)
 
-        # 创建生命周期管理器
+        # 创建组合生命周期管理器
         @asynccontextmanager
-        async def lifespan(app: FastAPI) -> AsyncGenerator[None, None]:
-            # 启动阶段 - 执行初始化
+        async def combined_lifespan(app: FastAPI) -> AsyncGenerator[None, None]:
+            # 1. 执行Services自身的初始化
             instance = cls(config, app)
-
-            # 检查是否存在监听器
             has_listeners = bool(
                 rabbitmq_listeners and len(rabbitmq_listeners) > 0)
-            # 检查是否存在发送器
-            has_senders = bool(
-                rabbitmq_senders and len(rabbitmq_senders) > 0)
+            has_senders = bool(rabbitmq_senders and len(rabbitmq_senders) > 0)
 
-            # 执行MQ异步初始化，传递是否有监听器的标志
             try:
                 await instance._setup_mq_async(
                     rabbitmq_listeners=rabbitmq_listeners,
@@ -93,22 +99,26 @@ class Services(metaclass=SingletonMeta):
                     has_senders=has_senders
                 )
                 cls._initialized = True
-                logging.info("所有服务初始化完成")
+                logging.info("Services初始化完成")
             except Exception as e:
-                logging.error(f"服务初始化失败: {str(e)}", exc_info=True)
+                logging.error(f"Services初始化失败: {str(e)}", exc_info=True)
                 raise
 
-            # 将实例挂载到app上
             app.state.services = instance
 
-            yield  # 应用运行阶段
+            # 2. 执行用户定义的生命周期
+            if cls._user_lifespan:
+                async with cls._user_lifespan(app):
+                    yield  # 应用运行阶段
+            else:
+                yield  # 没有用户生命周期时直接 yield
 
-            # 关闭阶段 - 清理资源
+            # 3. 执行Services的关闭逻辑
             await cls.shutdown()
-            logging.info("所有服务已关闭")
+            logging.info("Services已关闭")
 
-        # 设置生命周期
-        app.router.lifespan_context = lifespan
+        # 设置组合生命周期
+        app.router.lifespan_context = combined_lifespan
 
         return app
 
